@@ -343,7 +343,7 @@ const char *cql_lookup_reverse(cql_transform_t ct,
                     Z_AttributeElement a_ae = *attributes->attributes[j];
                     if (!compare_attr(e_ae, &a_ae))
                         break;
-                    if (a_ae.attributeSet && &e_ae->attributeSet &&
+                    if (a_ae.attributeSet && e_ae->attributeSet &&
                         !oid_oidcmp(a_ae.attributeSet, yaz_oid_attset_bib_1))
                         a_ae.attributeSet = 0;
                     if (!compare_attr(e_ae, &a_ae))
@@ -1046,4 +1046,3 @@ void cql_transform_set_error(cql_transform_t ct, int error, const char *addinfo)
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
  */
-
